﻿using System.IO;
using System.IO.IsolatedStorage;
using System.Linq;
using System.Windows;
using Hierchical.Model;
using Infragistics.Controls.Charts;
using Infragistics.Persistence;

namespace Hierchical
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private const string DiagramFileName = "EmployeeDiagramLayout.xml";
        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = new MainWindowViewModel();
        }

        private void OnSelectedNodeChanged(object sender, DiagramSelectionChangedEventArgs e)
        {
            if (e.AddedItems.Any())
            {
                ((MainWindowViewModel)this.DataContext).SelectedEmployee = e.AddedItems[0].Content as Employee;
            }
            else ((MainWindowViewModel)this.DataContext).SelectedEmployee = null;
        }

        private void SaveButtonOnClick(object sender, RoutedEventArgs e)
        {
            var memoryStream = PersistenceManager.Save(this.EmployesDiagram);
            using (var file = IsolatedStorageFile.GetStore(IsolatedStorageScope.User | IsolatedStorageScope.Domain | IsolatedStorageScope.Assembly, null, null))
            {
                if (file.FileExists(DiagramFileName)) file.DeleteFile(DiagramFileName);

                using (IsolatedStorageFileStream stream = new IsolatedStorageFileStream(DiagramFileName, FileMode.OpenOrCreate, file))
                {
                    // Write file in the isolated storage
                    stream.Write(memoryStream.ToArray(), 0, (int)memoryStream.Length);
                }
            }
        }

        private void LoadButtonOnClick(object sender, RoutedEventArgs e)
        {
            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore(IsolatedStorageScope.User | IsolatedStorageScope.Domain | IsolatedStorageScope.Assembly, null, null))
            {
                if (file.FileExists(DiagramFileName))
                {
                    using (IsolatedStorageFileStream stream = new IsolatedStorageFileStream(DiagramFileName, FileMode.OpenOrCreate, file))
                    {
                        PersistenceManager.Load(EmployesDiagram, stream);
                        EmployesDiagram.RefreshLayout();
                    }
                }
            }
        }
    }
}
